==> migrate_wizard-2.0.8-alpha1.tar.gz: migrate_wizard/src/Drush/Commands/MWDrushToolsCommands.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

declare(strict_types = 1);

namespace Drupal\migrate_wizard\Drush\Commands;

use Consolidation\OutputFormatters\StructuredData\RowsOfFields;
use Drupal\Component\Graph\Graph;
use Drupal\Component\Plugin\Exception\PluginNotFoundException;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Database\Database;
use Drupal\Core\Datetime\DateFormatter;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\KeyValueStore\KeyValueFactoryInterface;
use Drupal\migrate\Exception\RequirementsException;
use Drupal\migrate\Plugin\MigrationInterface;
use Drupal\migrate\Plugin\MigrationPluginManager;
use Drupal\migrate\Plugin\RequirementsInterface;
use Drupal\migrate_tools\Drush9LogMigrateMessage;
use Drupal\migrate_tools\IdMapFilter;
use Drupal\migrate_tools\MigrateExecutable;
use Drupal\migrate_tools\MigrateTools;
use Drush\Attributes as CLI;
use Drush\Commands\DrushCommands;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\migrate_tools\Drush\Commands\MigrateToolsCommands;

/**
 * Migrate Tools drush commands.
 */
class MWDrushToolsCommands extends MigrateToolsCommands {
  protected $migrate_wizard_settings;
  protected $mw_databases;
  public function __construct(MigrationPluginManager $migrationPluginManager, DateFormatter $dateFormatter, EntityTypeManagerInterface $entityTypeManager, KeyValueFactoryInterface $keyValue, ConfigFactoryInterface $configFactory) {
    parent::__construct($migrationPluginManager, $dateFormatter, $entityTypeManager, $keyValue);

    $this->migrate_wizard_settings = $configFactory->getEditable('migrate_wizard.settings')->get('migrate_wizard_settings');

    $this->mw_databases = $this->entityTypeManager->getStorage('mw_database')->loadMultiple();
    foreach($this->mw_databases as $mw_database){
      $info = [
        'host' => $mw_database->get('use_env') ? getenv($mw_database->get('host')) : $mw_database->get('host'),
        'database' => $mw_database->get('use_env') ? getenv($mw_database->get('database')) : $mw_database->get('database'),
        'username' => $mw_database->get('use_env') ? getenv($mw_database->get('username')) : $mw_database->get('username'),
        'password' => $mw_database->get('use_env') ? getenv($mw_database->get('password')) : $mw_database->get('password'),
        'prefix' => $mw_database->get('prefix'),
        'driver' => $mw_database->get('driver'),
        'port' => $mw_database->get('port'),
        'namespace' => $mw_database->get('namespace'),
        'collation' => $mw_database->get('collation'),
      ];
      Database::addConnectionInfo($mw_database->get('key'), $mw_database->get('target'), $info);
    }
  }
  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('plugin.manager.migration'),
      $container->get('date.formatter'),
      $container->get('entity_type.manager'),
      $container->get('keyvalue'),
      $container->get('config.factory')
    );
  }

 /**
   * {@inheritdoc}
   */
  #[CLI\Command(name: 'migrate:status', aliases: ['ms', 'migrate-status'])]
  #[CLI\Argument(name: 'migration_names', description: 'Restrict to a comma-separated list of migrations. Optional.')]
  #[CLI\Option(name: 'group', description: 'A comma-separated list of migration groups to import')]
  #[CLI\Option(name: 'tag', description: 'Name of the migration tag to list')]
  #[CLI\Option(name: 'names-only', description: 'Only return names, not all the details (faster)')]
  #[CLI\Option(name: 'continue-on-failure', description: 'When a migration fails, continue processing remaining migrations.')]
  #[CLI\Usage(name: 'migrate:status', description: 'Retrieve status for all migrations')]
  #[CLI\Usage(name: 'migrate:status --group=beer', description: 'Retrieve status for all migrations, grouped by tag')]
  #[CLI\Usage(name: 'migrate:status --tag=user', description: 'Retrieve status for all migrations tagged with user.')]
  #[CLI\Usage(name: 'migrate:status beer_term,beer_node', description: 'Retrieve status for specific migrations')]
  #[CLI\Usage(name: 'migrate:status --field=id', description: 'Retrieve a raw list of migration IDs.')]
  #[CLI\Usage(name: 'ms --fields=id,status --format=json', description: 'Retrieve a JSON serialized list of migrations, each item containing only the migration ID and its status.')]
  #[CLI\Topics(topics: ['migrate'])]
  #[CLI\ValidateModulesEnabled(modules: ['migrate_tools'])]
  #[CLI\FieldLabels(labels: ['group' => 'Group', 'id' => 'Migration ID', 'status' => 'Status', 'total' => 'Total', 'imported' => 'Imported', 'unprocessed' => 'Unprocessed', 'message_count' => 'Message Count', 'last_imported' => 'Last Imported'])]
  #[CLI\DefaultFields(fields: ['group', 'id', 'status', 'total', 'imported', 'unprocessed', 'message_count', 'last_imported'])]
  #[CLI\FilterDefaultField(field: 'status')]
  public function status($migration_names = '', array $options = [
    'group' => self::REQ,
    'tag' => self::REQ,
    'names-only' => FALSE,
    'continue-on-failure' => FALSE,
  ]): RowsOfFields {
    $table = [];
    foreach($this->mw_databases as $mw_database){
      Database::setActiveConnection($mw_database->get('key'));
      $options["group"] = $mw_database->get('migration_group');
      $table = parent::status($migration_names, $options);
    }

    return new RowsOfFields($table);
  }
}

==> migrate_wizard-2.0.9-alpha1.tar.gz: migrate_wizard/src/Drush/Commands/MWDrushToolsCommands.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

declare(strict_types = 1);

namespace Drupal\migrate_wizard\Drush\Commands;

use Consolidation\OutputFormatters\StructuredData\RowsOfFields;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Database\Database;
use Drupal\Core\Datetime\DateFormatter;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\KeyValueStore\KeyValueFactoryInterface;
use Drupal\migrate\Plugin\MigrationPluginManager;
use Drupal\migrate_tools\Drush\Commands\MigrateToolsCommands;
use Drush\Attributes as CLI;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Migrate Tools drush commands.
 */
class MWDrushToolsCommands extends MigrateToolsCommands {

  protected $migrate_wizard_settings;

  protected $mw_databases;

  public function __construct(MigrationPluginManager $migrationPluginManager, DateFormatter $dateFormatter, EntityTypeManagerInterface $entityTypeManager, KeyValueFactoryInterface $keyValue, ConfigFactoryInterface $configFactory) {
    parent::__construct($migrationPluginManager, $dateFormatter, $entityTypeManager, $keyValue);

    $this->migrate_wizard_settings = $configFactory->getEditable('migrate_wizard.settings')->get('migrate_wizard_settings');

    $this->mw_databases = $this->entityTypeManager->getStorage('mw_database')->loadMultiple();

    foreach ($this->mw_databases as $mw_database) {
      $info = [
        'host' => $mw_database->get('use_env') ? getenv($mw_database->get('host')) : $mw_database->get('host'),
        'database' => $mw_database->get('use_env') ? getenv($mw_database->get('database')) : $mw_database->get('database'),
        'username' => $mw_database->get('use_env') ? getenv($mw_database->get('username')) : $mw_database->get('username'),
        'password' => $mw_database->get('use_env') ? getenv($mw_database->get('password')) : $mw_database->get('password'),
        'prefix' => $mw_database->get('prefix'),
        'driver' => $mw_database->get('driver'),
        'port' => $mw_database->get('port'),
        'namespace' => $mw_database->get('namespace'),
        'collation' => $mw_database->get('collation'),
      ];
      Database::addConnectionInfo($mw_database->get('key'), $mw_database->get('target'), $info);
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('plugin.manager.migration'),
      $container->get('date.formatter'),
      $container->get('entity_type.manager'),
      $container->get('keyvalue'),
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  #[CLI\Command(name: 'migrate:status', aliases: ['ms', 'migrate-status'])]
  #[CLI\Argument(name: 'migration_names', description: 'Restrict to a comma-separated list of migrations. Optional.')]
  #[CLI\Option(name: 'group', description: 'A comma-separated list of migration groups to import')]
  #[CLI\Option(name: 'tag', description: 'Name of the migration tag to list')]
  #[CLI\Option(name: 'names-only', description: 'Only return names, not all the details (faster)')]
  #[CLI\Option(name: 'continue-on-failure', description: 'When a migration fails, continue processing remaining migrations.')]
  #[CLI\Usage(name: 'migrate:status', description: 'Retrieve status for all migrations')]
  #[CLI\Usage(name: 'migrate:status --group=beer', description: 'Retrieve status for all migrations, grouped by tag')]
  #[CLI\Usage(name: 'migrate:status --tag=user', description: 'Retrieve status for all migrations tagged with user.')]
  #[CLI\Usage(name: 'migrate:status beer_term,beer_node', description: 'Retrieve status for specific migrations')]
  #[CLI\Usage(name: 'migrate:status --field=id', description: 'Retrieve a raw list of migration IDs.')]
  #[CLI\Usage(name: 'ms --fields=id,status --format=json', description: 'Retrieve a JSON serialized list of migrations, each item containing only the migration ID and its status.')]
  #[CLI\Topics(topics: ['migrate'])]
  #[CLI\ValidateModulesEnabled(modules: ['migrate_tools'])]
  #[CLI\FieldLabels(labels: ['group' => 'Group', 'id' => 'Migration ID', 'status' => 'Status', 'total' => 'Total', 'imported' => 'Imported', 'unprocessed' => 'Unprocessed', 'message_count' => 'Message Count', 'last_imported' => 'Last Imported'])]
  #[CLI\DefaultFields(fields: ['group', 'id', 'status', 'total', 'imported', 'unprocessed', 'message_count', 'last_imported'])]
  #[CLI\FilterDefaultField(field: 'status')]
  public function status($migration_names = '', array $options = [
    'group' => self::REQ,
    'tag' => self::REQ,
    'names-only' => FALSE,
    'continue-on-failure' => FALSE,
  ]): RowsOfFields {
    $table = [];

    foreach ($this->mw_databases as $mw_database) {
      Database::setActiveConnection($mw_database->get('key'));
      $options['group'] = $mw_database->get('migration_group');
      $table = parent::status($migration_names, $options);
    }

    return new RowsOfFields($table);
  }

}
